from os.path import abspath, dirname, join

from caosadvancedtools.serverside.helper import get_data
from linkahead import Record, configure_connection, get_connection
from linkahead.connection.mockup import MockUpResponse, MockUpServerConnection
from loan.box_loan import (BORROWER, BOX, BOX_NUMBER, COMMENT, DESTINATION, EMAIL, EXHAUST_CONTENTS,
                           EXPECTED_RETURN, F_EMAIL, F_EXPECTED_RETURN_DATE, F_FIRST_NAME,
                           FIRST_NAME, PERSON, DataError)
from loan.request_loan import _issue_loan_request, create_loan
from pytest import raises

from utils import get_form_data_example


def test_issue_loan_request_with_wrong_return_date():
    data = get_data(get_form_data_example())
    data[F_EXPECTED_RETURN_DATE] = "1983-02-03"
    with raises(DataError):
        _issue_loan_request(data)


def test_create_loan():
    borrower = Record(name="Person1")
    loan = create_loan(1234, borrower, "2020-03-23", False, "blablabla", "my office")
    assert loan.get_property(BOX.name).value == 1234
    assert loan.get_property(BORROWER.name).value == borrower
    assert loan.get_property(EXPECTED_RETURN.name).value == "2020-03-23"
    assert loan.get_property(EXHAUST_CONTENTS.name).value is False
    assert loan.get_property(COMMENT.name).value == "blablabla"
    assert loan.get_property(DESTINATION.name).value == "my office"
